sparklines: <Add Title>

Description Usage Arguments

Description

<Add Description>

Output and render functions for using sparklines within Shiny applications and interactive Rmd documents.

Usage

1
2
3
4
5
sparklines(data, ...)

sparklinesOutput(outputId, width = "100%", height = "400px")

renderSparklines(expr, env = parent.frame(), quoted = FALSE)

Arguments

outputId

output variable to read from

width, height

Must be a valid CSS unit (like '100%', '400px', 'auto') or a number, which will be coerced to a string and have 'px' appended.

expr

An expression that generates a sparklines

env

The environment in which to evaluate expr.

quoted

Is expr a quoted expression (with quote())? This is useful if you want to save an expression in a variable.


react-R/sparklines-example documentation built on May 14, 2019, 8:50 p.m.